from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.collections import Collections

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.items_offset_paginated import ItemsOffsetPaginated

from box_sdk_gen.schemas.collection import Collection

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class CollectionsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_collections(
        self,
        *,
        fields: Optional[List[str]] = None,
        offset: Optional[int] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Collections:
        """
                Retrieves all collections for a given user.

                Currently, only the `favorites` collection


                is supported.

                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param offset: The offset of the item at which to begin the response.

        Queries with offset parameter value
        exceeding 10000 will be rejected
        with a 400 response., defaults to None
                :type offset: Optional[int], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'fields': to_string(fields),
                'offset': to_string(offset),
                'limit': to_string(limit),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/collections']
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Collections)

    def get_collection_items(
        self,
        collection_id: str,
        *,
        fields: Optional[List[str]] = None,
        offset: Optional[int] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ItemsOffsetPaginated:
        """
                Retrieves the files and/or folders contained within

                this collection.

                :param collection_id: The ID of the collection.
        Example: "926489"
                :type collection_id: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param offset: The offset of the item at which to begin the response.

        Queries with offset parameter value
        exceeding 10000 will be rejected
        with a 400 response., defaults to None
                :type offset: Optional[int], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'fields': to_string(fields),
                'offset': to_string(offset),
                'limit': to_string(limit),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/collections/',
                        to_string(collection_id),
                        '/items',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, ItemsOffsetPaginated)

    def get_collection_by_id(
        self,
        collection_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Collection:
        """
                Retrieves a collection by its ID.
                :param collection_id: The ID of the collection.
        Example: "926489"
                :type collection_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/collections/',
                        to_string(collection_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Collection)



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.utils import Date

from box_sdk_gen.schemas.sign_request_signer_input_email_validation import (
    SignRequestSignerInputEmailValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_custom_validation import (
    SignRequestSignerInputCustomValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_zip_validation import (
    SignRequestSignerInputZipValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_zip_4_validation import (
    SignRequestSignerInputZip4Validation,
)

from box_sdk_gen.schemas.sign_request_signer_input_ssn_validation import (
    SignRequestSignerInputSsnValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_number_with_period_validation import (
    SignRequestSignerInputNumberWithPeriodValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_number_with_comma_validation import (
    SignRequestSignerInputNumberWithCommaValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_date_iso_validation import (
    SignRequestSignerInputDateIsoValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_date_us_validation import (
    SignRequestSignerInputDateUsValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_date_eu_validation import (
    SignRequestSignerInputDateEuValidation,
)

from box_sdk_gen.schemas.sign_request_signer_input_date_asia_validation import (
    SignRequestSignerInputDateAsiaValidation,
)

from box_sdk_gen.schemas.sign_request_prefill_tag import SignRequestPrefillTag

from box_sdk_gen.schemas.sign_request_signer_input_validation import (
    SignRequestSignerInputValidation,
)

from box_sdk_gen.box.errors import BoxSDKError


class SignRequestSignerInputTypeField(str, Enum):
    SIGNATURE = 'signature'
    DATE = 'date'
    TEXT = 'text'
    CHECKBOX = 'checkbox'
    RADIO = 'radio'
    DROPDOWN = 'dropdown'


class SignRequestSignerInputContentTypeField(str, Enum):
    SIGNATURE = 'signature'
    INITIAL = 'initial'
    STAMP = 'stamp'
    DATE = 'date'
    CHECKBOX = 'checkbox'
    TEXT = 'text'
    FULL_NAME = 'full_name'
    FIRST_NAME = 'first_name'
    LAST_NAME = 'last_name'
    COMPANY = 'company'
    TITLE = 'title'
    EMAIL = 'email'
    ATTACHMENT = 'attachment'
    RADIO = 'radio'
    DROPDOWN = 'dropdown'


class SignRequestSignerInput(SignRequestPrefillTag):
    def __init__(
        self,
        page_index: int,
        *,
        type: Optional[SignRequestSignerInputTypeField] = None,
        content_type: Optional[SignRequestSignerInputContentTypeField] = None,
        read_only: Optional[bool] = None,
        validation: Optional[SignRequestSignerInputValidation] = None,
        document_tag_id: Optional[str] = None,
        text_value: Optional[str] = None,
        checkbox_value: Optional[bool] = None,
        date_value: Optional[Date] = None,
        **kwargs
    ):
        """
                :param page_index: Index of page that the input is on.
                :type page_index: int
                :param type: Type of input., defaults to None
                :type type: Optional[SignRequestSignerInputTypeField], optional
                :param content_type: Content type of input., defaults to None
                :type content_type: Optional[SignRequestSignerInputContentTypeField], optional
                :param read_only: Indicates whether this input is read-only (cannot be modified by signers)., defaults to None
                :type read_only: Optional[bool], optional
                :param validation: Specifies the formatting rules that signers must follow for text field inputs.
        If set, this validation is mandatory., defaults to None
                :type validation: Optional[SignRequestSignerInputValidation], optional
                :param document_tag_id: This references the ID of a specific tag contained in a file of the signature request., defaults to None
                :type document_tag_id: Optional[str], optional
                :param text_value: Text prefill value., defaults to None
                :type text_value: Optional[str], optional
                :param checkbox_value: Checkbox prefill value., defaults to None
                :type checkbox_value: Optional[bool], optional
                :param date_value: Date prefill value., defaults to None
                :type date_value: Optional[Date], optional
        """
        super().__init__(
            document_tag_id=document_tag_id,
            text_value=text_value,
            checkbox_value=checkbox_value,
            date_value=date_value,
            **kwargs
        )
        self.page_index = page_index
        self.type = type
        self.content_type = content_type
        self.read_only = read_only
        self.validation = validation



from typing import Optional

from box_sdk_gen.schemas.file_version_base import FileVersionBaseTypeField

from box_sdk_gen.schemas.file_version_base import FileVersionBase

from box_sdk_gen.schemas.file_version_mini import FileVersionMini

from box_sdk_gen.internal.utils import DateTime

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.schemas.file_version import FileVersion

from box_sdk_gen.box.errors import BoxSDKError


class FileVersionFull(FileVersion):
    def __init__(
        self,
        id: str,
        *,
        version_number: Optional[str] = None,
        name: Optional[str] = None,
        size: Optional[int] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        modified_by: Optional[UserMini] = None,
        trashed_at: Optional[DateTime] = None,
        trashed_by: Optional[UserMini] = None,
        restored_at: Optional[DateTime] = None,
        restored_by: Optional[UserMini] = None,
        purged_at: Optional[DateTime] = None,
        uploader_display_name: Optional[str] = None,
        sha_1: Optional[str] = None,
        type: FileVersionBaseTypeField = FileVersionBaseTypeField.FILE_VERSION,
        **kwargs
    ):
        """
        :param id: The unique identifier that represent a file version.
        :type id: str
        :param version_number: The version number of this file version., defaults to None
        :type version_number: Optional[str], optional
        :param name: The name of the file version., defaults to None
        :type name: Optional[str], optional
        :param size: Size of the file version in bytes., defaults to None
        :type size: Optional[int], optional
        :param created_at: When the file version object was created., defaults to None
        :type created_at: Optional[DateTime], optional
        :param modified_at: When the file version object was last updated., defaults to None
        :type modified_at: Optional[DateTime], optional
        :param trashed_at: When the file version object was trashed., defaults to None
        :type trashed_at: Optional[DateTime], optional
        :param restored_at: When the file version was restored from the trash., defaults to None
        :type restored_at: Optional[DateTime], optional
        :param purged_at: When the file version object will be permanently deleted., defaults to None
        :type purged_at: Optional[DateTime], optional
        :param sha_1: The SHA1 hash of this version of the file., defaults to None
        :type sha_1: Optional[str], optional
        :param type: The value will always be `file_version`., defaults to FileVersionBaseTypeField.FILE_VERSION
        :type type: FileVersionBaseTypeField, optional
        """
        super().__init__(
            id=id,
            name=name,
            size=size,
            created_at=created_at,
            modified_at=modified_at,
            modified_by=modified_by,
            trashed_at=trashed_at,
            trashed_by=trashed_by,
            restored_at=restored_at,
            restored_by=restored_by,
            purged_at=purged_at,
            uploader_display_name=uploader_display_name,
            sha_1=sha_1,
            type=type,
            **kwargs
        )
        self.version_number = version_number



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.file import File

from box_sdk_gen.schemas.folder import Folder

from box_sdk_gen.schemas.web_link import WebLink

from box_sdk_gen.schemas.group_mini import GroupMini

from box_sdk_gen.schemas.collaboration_item import CollaborationItem

from box_sdk_gen.schemas.app_item import AppItem

from box_sdk_gen.schemas.collaboration_access_grantee import CollaborationAccessGrantee

from box_sdk_gen.schemas.user_collaborations import UserCollaborations

from box_sdk_gen.schemas.terms_of_service_base import TermsOfServiceBase

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class CollaborationTypeField(str, Enum):
    COLLABORATION = 'collaboration'


class CollaborationRoleField(str, Enum):
    EDITOR = 'editor'
    VIEWER = 'viewer'
    PREVIEWER = 'previewer'
    UPLOADER = 'uploader'
    PREVIEWER_UPLOADER = 'previewer uploader'
    VIEWER_UPLOADER = 'viewer uploader'
    CO_OWNER = 'co-owner'
    OWNER = 'owner'


class CollaborationStatusField(str, Enum):
    ACCEPTED = 'accepted'
    PENDING = 'pending'
    REJECTED = 'rejected'


class CollaborationAcceptanceRequirementsStatusTermsOfServiceRequirementField(
    BaseObject
):
    def __init__(
        self,
        *,
        is_accepted: Optional[bool] = None,
        terms_of_service: Optional[TermsOfServiceBase] = None,
        **kwargs
    ):
        """
                :param is_accepted: Whether or not the terms of service have been accepted.  The
        field is `null` when there is no terms of service required., defaults to None
                :type is_accepted: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.is_accepted = is_accepted
        self.terms_of_service = terms_of_service


class CollaborationAcceptanceRequirementsStatusStrongPasswordRequirementField(
    BaseObject
):
    def __init__(
        self,
        *,
        enterprise_has_strong_password_required_for_external_users: Optional[
            bool
        ] = None,
        user_has_strong_password: Optional[bool] = None,
        **kwargs
    ):
        """
                :param enterprise_has_strong_password_required_for_external_users: Whether or not the enterprise that owns the content requires
        a strong password to collaborate on the content, or enforces
        an exposed password detection for the external collaborators., defaults to None
                :type enterprise_has_strong_password_required_for_external_users: Optional[bool], optional
                :param user_has_strong_password: Whether or not the user has a strong and not exposed password set
        for their account. The field is `null` when a strong password is
        not required., defaults to None
                :type user_has_strong_password: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.enterprise_has_strong_password_required_for_external_users = (
            enterprise_has_strong_password_required_for_external_users
        )
        self.user_has_strong_password = user_has_strong_password


class CollaborationAcceptanceRequirementsStatusTwoFactorAuthenticationRequirementField(
    BaseObject
):
    def __init__(
        self,
        *,
        enterprise_has_two_factor_auth_enabled: Optional[bool] = None,
        user_has_two_factor_authentication_enabled: Optional[bool] = None,
        **kwargs
    ):
        """
                :param enterprise_has_two_factor_auth_enabled: Whether or not the enterprise that owns the content requires
        two-factor authentication to be enabled in order to
        collaborate on the content., defaults to None
                :type enterprise_has_two_factor_auth_enabled: Optional[bool], optional
                :param user_has_two_factor_authentication_enabled: Whether or not the user has two-factor authentication
        enabled. The field is `null` when two-factor
        authentication is not required., defaults to None
                :type user_has_two_factor_authentication_enabled: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.enterprise_has_two_factor_auth_enabled = (
            enterprise_has_two_factor_auth_enabled
        )
        self.user_has_two_factor_authentication_enabled = (
            user_has_two_factor_authentication_enabled
        )


class CollaborationAcceptanceRequirementsStatusField(BaseObject):
    def __init__(
        self,
        *,
        terms_of_service_requirement: Optional[
            CollaborationAcceptanceRequirementsStatusTermsOfServiceRequirementField
        ] = None,
        strong_password_requirement: Optional[
            CollaborationAcceptanceRequirementsStatusStrongPasswordRequirementField
        ] = None,
        two_factor_authentication_requirement: Optional[
            CollaborationAcceptanceRequirementsStatusTwoFactorAuthenticationRequirementField
        ] = None,
        **kwargs
    ):
        super().__init__(**kwargs)
        self.terms_of_service_requirement = terms_of_service_requirement
        self.strong_password_requirement = strong_password_requirement
        self.two_factor_authentication_requirement = (
            two_factor_authentication_requirement
        )


class Collaboration(BaseObject):
    _discriminator = 'type', {'collaboration'}

    def __init__(
        self,
        id: str,
        *,
        type: CollaborationTypeField = CollaborationTypeField.COLLABORATION,
        item: Optional[CollaborationItem] = None,
        app_item: Optional[AppItem] = None,
        accessible_by: Optional[CollaborationAccessGrantee] = None,
        invite_email: Optional[str] = None,
        role: Optional[CollaborationRoleField] = None,
        expires_at: Optional[DateTime] = None,
        is_access_only: Optional[bool] = None,
        status: Optional[CollaborationStatusField] = None,
        acknowledged_at: Optional[DateTime] = None,
        created_by: Optional[UserCollaborations] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        acceptance_requirements_status: Optional[
            CollaborationAcceptanceRequirementsStatusField
        ] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for this collaboration.
                :type id: str
                :param type: The value will always be `collaboration`., defaults to CollaborationTypeField.COLLABORATION
                :type type: CollaborationTypeField, optional
                :param invite_email: The email address used to invite an unregistered collaborator, if
        they are not a registered user., defaults to None
                :type invite_email: Optional[str], optional
                :param role: The level of access granted., defaults to None
                :type role: Optional[CollaborationRoleField], optional
                :param expires_at: When the collaboration will expire, or `null` if no expiration
        date is set., defaults to None
                :type expires_at: Optional[DateTime], optional
                :param is_access_only: If set to `true`, collaborators have access to
        shared items, but such items won't be visible in the
        All Files list. Additionally, collaborators won't
        see the path to the root folder for the
        shared item., defaults to None
                :type is_access_only: Optional[bool], optional
                :param status: The status of the collaboration invitation. If the status
        is `pending`, `login` and `name` return an empty string., defaults to None
                :type status: Optional[CollaborationStatusField], optional
                :param acknowledged_at: When the `status` of the collaboration object changed to
        `accepted` or `rejected`., defaults to None
                :type acknowledged_at: Optional[DateTime], optional
                :param created_at: When the collaboration object was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param modified_at: When the collaboration object was last modified., defaults to None
                :type modified_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.item = item
        self.app_item = app_item
        self.accessible_by = accessible_by
        self.invite_email = invite_email
        self.role = role
        self.expires_at = expires_at
        self.is_access_only = is_access_only
        self.status = status
        self.acknowledged_at = acknowledged_at
        self.created_by = created_by
        self.created_at = created_at
        self.modified_at = modified_at
        self.acceptance_requirements_status = acceptance_requirements_status



from typing import Optional

from box_sdk_gen.schemas.v2025_r0.file_reference_v2025_r0 import FileReferenceV2025R0

from box_sdk_gen.schemas.v2025_r0.doc_gen_template_base_v2025_r0 import (
    DocGenTemplateBaseV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError


class DocGenTemplateV2025R0(DocGenTemplateBaseV2025R0):
    def __init__(
        self,
        *,
        file_name: Optional[str] = None,
        file: Optional[FileReferenceV2025R0] = None,
        **kwargs
    ):
        """
        :param file_name: The name of the template., defaults to None
        :type file_name: Optional[str], optional
        """
        super().__init__(file=file, **kwargs)
        self.file_name = file_name



from box_sdk_gen.internal.base_object import BaseObject

from enum import Enum

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.internal.null_value import NullValue

from typing import Union

from typing import List

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.group_memberships import GroupMemberships

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.group_membership import GroupMembership

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class CreateGroupMembershipUser(BaseObject):
    def __init__(self, id: str, **kwargs):
        """
        :param id: The ID of the user to add to the group.
        :type id: str
        """
        super().__init__(**kwargs)
        self.id = id


class CreateGroupMembershipGroup(BaseObject):
    def __init__(self, id: str, **kwargs):
        """
        :param id: The ID of the group to add the user to.
        :type id: str
        """
        super().__init__(**kwargs)
        self.id = id


class CreateGroupMembershipRole(str, Enum):
    MEMBER = 'member'
    ADMIN = 'admin'


class UpdateGroupMembershipByIdRole(str, Enum):
    MEMBER = 'member'
    ADMIN = 'admin'


class MembershipsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_user_memberships(
        self,
        user_id: str,
        *,
        limit: Optional[int] = None,
        offset: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> GroupMemberships:
        """
                Retrieves all the groups for a user. Only members of this

                group or users with admin-level permissions will be able to


                use this API.

                :param user_id: The ID of the user.
        Example: "12345"
                :type user_id: str
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param offset: The offset of the item at which to begin the response.

        Queries with offset parameter value
        exceeding 10000 will be rejected
        with a 400 response., defaults to None
                :type offset: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'limit': to_string(limit), 'offset': to_string(offset)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/users/',
                        to_string(user_id),
                        '/memberships',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, GroupMemberships)

    def get_group_memberships(
        self,
        group_id: str,
        *,
        limit: Optional[int] = None,
        offset: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> GroupMemberships:
        """
                Retrieves all the members for a group. Only members of this

                group or users with admin-level permissions will be able to


                use this API.

                :param group_id: The ID of the group.
        Example: "57645"
                :type group_id: str
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param offset: The offset of the item at which to begin the response.

        Queries with offset parameter value
        exceeding 10000 will be rejected
        with a 400 response., defaults to None
                :type offset: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'limit': to_string(limit), 'offset': to_string(offset)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/groups/',
                        to_string(group_id),
                        '/memberships',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, GroupMemberships)

    def create_group_membership(
        self,
        user: CreateGroupMembershipUser,
        group: CreateGroupMembershipGroup,
        *,
        role: Optional[CreateGroupMembershipRole] = None,
        configurable_permissions: Union[Optional[Dict[str, bool]], NullValue] = None,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> GroupMembership:
        """
                Creates a group membership. Only users with

                admin-level permissions will be able to use this API.

                :param user: The user to add to the group.
                :type user: CreateGroupMembershipUser
                :param group: The group to add the user to.
                :type group: CreateGroupMembershipGroup
                :param role: The role of the user in the group., defaults to None
                :type role: Optional[CreateGroupMembershipRole], optional
                :param configurable_permissions: Custom configuration for the permissions an admin
        if a group will receive. This option has no effect
        on members with a role of `member`.

        Setting these permissions overwrites the default
        access levels of an admin.

        Specifying a value of `null` for this object will disable
        all configurable permissions. Specifying permissions will set
        them accordingly, omitted permissions will be enabled by default., defaults to None
                :type configurable_permissions: Union[Optional[Dict[str, bool]], NullValue], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'user': user,
            'group': group,
            'role': role,
            'configurable_permissions': configurable_permissions,
        }
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/group_memberships']
                ),
                method='POST',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, GroupMembership)

    def get_group_membership_by_id(
        self,
        group_membership_id: str,
        *,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> GroupMembership:
        """
                Retrieves a specific group membership. Only admins of this

                group or users with admin-level permissions will be able to


                use this API.

                :param group_membership_id: The ID of the group membership.
        Example: "434534"
                :type group_membership_id: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/group_memberships/',
                        to_string(group_membership_id),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, GroupMembership)

    def update_group_membership_by_id(
        self,
        group_membership_id: str,
        *,
        role: Optional[UpdateGroupMembershipByIdRole] = None,
        configurable_permissions: Union[Optional[Dict[str, bool]], NullValue] = None,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> GroupMembership:
        """
                Updates a user's group membership. Only admins of this

                group or users with admin-level permissions will be able to


                use this API.

                :param group_membership_id: The ID of the group membership.
        Example: "434534"
                :type group_membership_id: str
                :param role: The role of the user in the group., defaults to None
                :type role: Optional[UpdateGroupMembershipByIdRole], optional
                :param configurable_permissions: Custom configuration for the permissions an admin
        if a group will receive. This option has no effect
        on members with a role of `member`.

        Setting these permissions overwrites the default
        access levels of an admin.

        Specifying a value of `null` for this object will disable
        all configurable permissions. Specifying permissions will set
        them accordingly, omitted permissions will be enabled by default., defaults to None
                :type configurable_permissions: Union[Optional[Dict[str, bool]], NullValue], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'role': role,
            'configurable_permissions': configurable_permissions,
        }
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/group_memberships/',
                        to_string(group_membership_id),
                    ]
                ),
                method='PUT',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, GroupMembership)

    def delete_group_membership_by_id(
        self,
        group_membership_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes a specific group membership. Only admins of this

                group or users with admin-level permissions will be able to


                use this API.

                :param group_membership_id: The ID of the group membership.
        Example: "434534"
                :type group_membership_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/group_memberships/',
                        to_string(group_membership_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from setuptools import setup, find_packages

from os.path import dirname, join

import re


def main():
    install_requires = ['requests', 'requests-toolbelt']
    tests_require = [
        'pytest',
        'pytest-timeout',
        'pytest-cov',
        'pytest-rerunfailures',
        'pytest-xdist',
    ]
    dev_requires = ['tox']
    jwt_requires = ['pyjwt>=1.7.0', 'cryptography>=3']
    version_file = open(join(dirname(__file__), 'box_sdk_gen/networking/version.py'))
    version_regex = re.compile('.*__version__ = \'(.*?)\'', re.S)
    version_string_grouped = version_regex.match(version_file.read())
    __version__ = version_string_grouped.group(1)
    extras_require = {
        'test': tests_require + jwt_requires,
        'dev': dev_requires,
        'jwt': jwt_requires,
    }
    setup(
        name='boxsdk',
        version=__version__,
        description='Official Box Python SDK',
        url='https://github.com/box/box-python-sdk.git',
        licence='Apache-2.0, http://www.apache.org/licenses/LICENSE-2.0',
        author='Box',
        long_description_content_type='text/markdown',
        long_description=open(
            join(dirname(__file__), 'README.md'), encoding='utf-8'
        ).read(),
        author_email='oss@box.com',
        classifiers=[
            'Development Status :: 5 - Production/Stable',
            'Intended Audience :: Developers',
            'License :: OSI Approved :: Apache Software License',
            'Programming Language :: Python',
            'Programming Language :: Python :: 3.8',
            'Programming Language :: Python :: 3.9',
            'Programming Language :: Python :: 3.10',
            'Programming Language :: Python :: 3.11',
            'Programming Language :: Python :: 3.12',
            'Programming Language :: Python :: Implementation :: CPython',
            'Programming Language :: Python :: Implementation :: PyPy',
            'Operating System :: OS Independent',
            'Operating System :: POSIX',
            'Operating System :: Microsoft :: Windows',
            'Operating System :: MacOS :: MacOS X',
            'Topic :: Software Development :: Libraries :: Python Modules',
        ],
        keywords='box, sdk, api, rest, boxsdk, box-sdk-gen',
        install_requires=install_requires,
        tests_require=tests_require,
        extras_require=extras_require,
        packages=find_packages(exclude=['docs', '*test*']),
    )


if __name__ == '__main__':
    main()



from typing import Optional

from typing import List

from box_sdk_gen.schemas.post_o_auth_2_token import PostOAuth2TokenGrantTypeField

from box_sdk_gen.schemas.post_o_auth_2_token import PostOAuth2TokenSubjectTokenTypeField

from box_sdk_gen.schemas.access_token import AccessToken

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.box.token_storage import TokenStorage

from box_sdk_gen.box.token_storage import InMemoryTokenStorage

from box_sdk_gen.managers.authorization import AuthorizationManager

from box_sdk_gen.schemas.post_o_auth_2_token import PostOAuth2Token

from box_sdk_gen.schemas.post_o_auth_2_revoke import PostOAuth2Revoke


class DeveloperTokenConfig:
    def __init__(
        self, *, client_id: Optional[str] = None, client_secret: Optional[str] = None
    ):
        self.client_id = client_id
        self.client_secret = client_secret


class BoxDeveloperTokenAuth(Authentication):
    def __init__(self, token: str, *, config: DeveloperTokenConfig = None, **kwargs):
        """
        :param config: Configuration object of DeveloperTokenAuth., defaults to None
        :type config: DeveloperTokenConfig, optional
        """
        super().__init__(**kwargs)
        self.token = token
        self.config = config
        self.token_storage = InMemoryTokenStorage(
            token=AccessToken(access_token=self.token)
        )

    def retrieve_token(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        """
        Retrieves stored developer token
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        token: Optional[AccessToken] = self.token_storage.get()
        if token == None:
            raise BoxSDKError(message='No access token is available.')
        return token

    def refresh_token(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        """
        Developer token cannot be refreshed
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        raise BoxSDKError(
            message='Developer token has expired. Please provide a new one.'
        )

    def retrieve_authorization_header(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> str:
        token: AccessToken = self.retrieve_token(network_session=network_session)
        return ''.join(['Bearer ', token.access_token])

    def revoke_token(self, *, network_session: Optional[NetworkSession] = None) -> None:
        """
        Revoke an active Access Token, effectively logging a user out that has been previously authenticated.
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        token: Optional[AccessToken] = self.token_storage.get()
        if token == None:
            return None
        auth_manager: AuthorizationManager = AuthorizationManager(
            network_session=(
                network_session if not network_session == None else NetworkSession()
            )
        )
        auth_manager.revoke_access_token(
            client_id=self.config.client_id,
            client_secret=self.config.client_secret,
            token=token.access_token,
        )
        self.token_storage.clear()
        return None

    def downscope_token(
        self,
        scopes: List[str],
        *,
        resource: Optional[str] = None,
        shared_link: Optional[str] = None,
        network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        """
        Downscope access token to the provided scopes. Returning a new access token with the provided scopes, with the original access token unchanged.
        :param scopes: The scope(s) to apply to the resulting token.
        :type scopes: List[str]
        :param resource: The file or folder to get a downscoped token for. If None and shared_link None, the resulting token will not be scoped down to just a single item. The resource should be a full URL to an item, e.g. https://api.box.com/2.0/files/123456., defaults to None
        :type resource: Optional[str], optional
        :param shared_link: The shared link to get a downscoped token for. If None and item None, the resulting token will not be scoped down to just a single item., defaults to None
        :type shared_link: Optional[str], optional
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        token: Optional[AccessToken] = self.retrieve_token(
            network_session=network_session
        )
        if token == None or token.access_token == None:
            raise BoxSDKError(message='No access token is available.')
        auth_manager: AuthorizationManager = AuthorizationManager(
            network_session=(
                network_session if not network_session == None else NetworkSession()
            )
        )
        downscoped_token: AccessToken = auth_manager.request_access_token(
            PostOAuth2TokenGrantTypeField.URN_IETF_PARAMS_OAUTH_GRANT_TYPE_TOKEN_EXCHANGE,
            subject_token=token.access_token,
            subject_token_type=PostOAuth2TokenSubjectTokenTypeField.URN_IETF_PARAMS_OAUTH_TOKEN_TYPE_ACCESS_TOKEN,
            resource=resource,
            scope=' '.join(scopes),
            box_shared_link=shared_link,
        )
        return downscoped_token



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import Dict

from typing import List

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.search_results import SearchResults

from box_sdk_gen.schemas.search_results_with_shared_links import (
    SearchResultsWithSharedLinks,
)

from box_sdk_gen.schemas.metadata_query_results import MetadataQueryResults

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.metadata_query import MetadataQuery

from box_sdk_gen.schemas.search_results_response import SearchResultsResponse

from box_sdk_gen.schemas.metadata_filter import MetadataFilter

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import SerializedData

from box_sdk_gen.serialization.json import sd_to_json


class SearchByMetadataQueryOrderByDirectionField(str, Enum):
    ASC = 'ASC'
    DESC = 'DESC'


class SearchByMetadataQueryOrderBy(BaseObject):
    def __init__(
        self,
        *,
        field_key: Optional[str] = None,
        direction: Optional[SearchByMetadataQueryOrderByDirectionField] = None,
        **kwargs
    ):
        """
                :param field_key: The metadata template field to order by.

        The `field_key` represents the `key` value of a field from the
        metadata template being searched for., defaults to None
                :type field_key: Optional[str], optional
                :param direction: The direction to order by, either ascending or descending.

        The `ordering` direction must be the same for each item in the
        array., defaults to None
                :type direction: Optional[SearchByMetadataQueryOrderByDirectionField], optional
        """
        super().__init__(**kwargs)
        self.field_key = field_key
        self.direction = direction


class SearchForContentScope(str, Enum):
    USER_CONTENT = 'user_content'
    ENTERPRISE_CONTENT = 'enterprise_content'


class SearchForContentContentTypes(str, Enum):
    NAME = 'name'
    DESCRIPTION = 'description'
    FILE_CONTENT = 'file_content'
    COMMENTS = 'comments'
    TAG = 'tag'


class SearchForContentType(str, Enum):
    FILE = 'file'
    FOLDER = 'folder'
    WEB_LINK = 'web_link'


class SearchForContentTrashContent(str, Enum):
    NON_TRASHED_ONLY = 'non_trashed_only'
    TRASHED_ONLY = 'trashed_only'
    ALL_ITEMS = 'all_items'


class SearchForContentSort(str, Enum):
    MODIFIED_AT = 'modified_at'
    RELEVANCE = 'relevance'


class SearchForContentDirection(str, Enum):
    DESC = 'DESC'
    ASC = 'ASC'


class SearchManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def search_by_metadata_query(
        self,
        from_: str,
        ancestor_folder_id: str,
        *,
        query: Optional[str] = None,
        query_params: Optional[Dict] = None,
        order_by: Optional[List[SearchByMetadataQueryOrderBy]] = None,
        limit: Optional[int] = None,
        marker: Optional[str] = None,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataQueryResults:
        """
                Create a search using SQL-like syntax to return items that match specific

                metadata.


                By default, this endpoint returns only the most basic info about the items for


                which the query matches. To get additional fields for each item, including any


                of the metadata, use the `fields` attribute in the query.

                :param from_: Specifies the template used in the query. Must be in the form
        `scope.templateKey`. Not all templates can be used in this field,
        most notably the built-in, Box-provided classification templates
        can not be used in a query.
                :type from_: str
                :param ancestor_folder_id: The ID of the folder that you are restricting the query to. A
        value of zero will return results from all folders you have access
        to. A non-zero value will only return results found in the folder
        corresponding to the ID or in any of its subfolders.
                :type ancestor_folder_id: str
                :param query: The query to perform. A query is a logical expression that is very similar
        to a SQL `SELECT` statement. Values in the search query can be turned into
        parameters specified in the `query_param` arguments list to prevent having
        to manually insert search values into the query string.

        For example, a value of `:amount` would represent the `amount` value in
        `query_params` object., defaults to None
                :type query: Optional[str], optional
                :param query_params: Set of arguments corresponding to the parameters specified in the
        `query`. The type of each parameter used in the `query_params` must match
        the type of the corresponding metadata template field., defaults to None
                :type query_params: Optional[Dict], optional
                :param order_by: A list of template fields and directions to sort the metadata query
        results by.

        The ordering `direction` must be the same for each item in the array., defaults to None
                :type order_by: Optional[List[SearchByMetadataQueryOrderBy]], optional
                :param limit: A value between 0 and 100 that indicates the maximum number of results
        to return for a single request. This only specifies a maximum
        boundary and will not guarantee the minimum number of results
        returned., defaults to None
                :type limit: Optional[int], optional
                :param marker: Marker to use for requesting the next page., defaults to None
                :type marker: Optional[str], optional
                :param fields: By default, this endpoint returns only the most basic info about the items for
        which the query matches. This attribute can be used to specify a list of
        additional attributes to return for any item, including its metadata.

        This attribute takes a list of item fields, metadata template identifiers,
        or metadata template field identifiers.

        For example:

        * `created_by` will add the details of the user who created the item to
        the response.
        * `metadata.<scope>.<templateKey>` will return the mini-representation
        of the metadata instance identified by the `scope` and `templateKey`.
        * `metadata.<scope>.<templateKey>.<field>` will return all the mini-representation
        of the metadata instance identified by the `scope` and `templateKey` plus
        the field specified by the `field` name. Multiple fields for the same
        `scope` and `templateKey` can be defined., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'from': from_,
            'query': query,
            'query_params': query_params,
            'ancestor_folder_id': ancestor_folder_id,
            'order_by': order_by,
            'limit': limit,
            'marker': marker,
            'fields': fields,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_queries/execute_read',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataQueryResults)

    def search_for_content(
        self,
        *,
        query: Optional[str] = None,
        scope: Optional[SearchForContentScope] = None,
        file_extensions: Optional[List[str]] = None,
        created_at_range: Optional[List[str]] = None,
        updated_at_range: Optional[List[str]] = None,
        size_range: Optional[List[int]] = None,
        owner_user_ids: Optional[List[str]] = None,
        recent_updater_user_ids: Optional[List[str]] = None,
        ancestor_folder_ids: Optional[List[str]] = None,
        content_types: Optional[List[SearchForContentContentTypes]] = None,
        type: Optional[SearchForContentType] = None,
        trash_content: Optional[SearchForContentTrashContent] = None,
        mdfilters: Optional[List[MetadataFilter]] = None,
        sort: Optional[SearchForContentSort] = None,
        direction: Optional[SearchForContentDirection] = None,
        limit: Optional[int] = None,
        include_recent_shared_links: Optional[bool] = None,
        fields: Optional[List[str]] = None,
        offset: Optional[int] = None,
        deleted_user_ids: Optional[List[str]] = None,
        deleted_at_range: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> SearchResultsResponse:
        """
                Searches for files, folders, web links, and shared files across the

                users content or across the entire enterprise.

                :param query: The string to search for. This query is matched against item names,
        descriptions, text content of files, and various other fields of
        the different item types.

        This parameter supports a variety of operators to further refine
        the results returns.

        * `""` - by wrapping a query in double quotes only exact matches are
          returned by the API. Exact searches do not return search matches
          based on specific character sequences. Instead, they return
          matches based on phrases, that is, word sequences. For example:
          A search for `"Blue-Box"` may return search results including
          the sequence `"blue.box"`, `"Blue Box"`, and `"Blue-Box"`;
          any item containing the words `Blue` and `Box` consecutively, in
          the order specified.
        * `AND` - returns items that contain both the search terms. For
          example, a search for `marketing AND BoxWorks` returns items
          that have both `marketing` and `BoxWorks` within its text in any order.
          It does not return a result that only has `BoxWorks` in its text.
        * `OR` - returns items that contain either of the search terms. For
          example, a search for `marketing OR BoxWorks` returns a result that
          has either `marketing` or `BoxWorks` within its text. Using this
          operator is not necessary as we implicitly interpret multi-word
          queries as `OR` unless another supported boolean term is used.
        * `NOT` - returns items that do not contain the search term provided.
          For example, a search for `marketing AND NOT BoxWorks` returns a result
          that has only `marketing` within its text. Results containing
          `BoxWorks` are omitted.

        We do not support lower case (that is,
        `and`, `or`, and `not`) or mixed case (that is, `And`, `Or`, and `Not`)
        operators.

        This field is required unless the `mdfilters` parameter is defined., defaults to None
                :type query: Optional[str], optional
                :param scope: Limits the search results to either the files that the user has
        access to, or to files available to the entire enterprise.

        The scope defaults to `user_content`, which limits the search
        results to content that is available to the currently authenticated
        user.

        The `enterprise_content` can be requested by an admin through our
        support channels. Once this scope has been enabled for a user, it
        will allow that use to query for content across the entire
        enterprise and not only the content that they have access to., defaults to None
                :type scope: Optional[SearchForContentScope], optional
                :param file_extensions: Limits the search results to any files that match any of the provided
        file extensions. This list is a comma-separated list of file extensions
        without the dots., defaults to None
                :type file_extensions: Optional[List[str]], optional
                :param created_at_range: Limits the search results to any items created within
        a given date range.

        Date ranges are defined as comma separated RFC3339
        timestamps.

        If the start date is omitted (`,2014-05-17T13:35:01-07:00`)
        anything created before the end date will be returned.

        If the end date is omitted (`2014-05-15T13:35:01-07:00,`) the
        current date will be used as the end date instead., defaults to None
                :type created_at_range: Optional[List[str]], optional
                :param updated_at_range: Limits the search results to any items updated within
        a given date range.

        Date ranges are defined as comma separated RFC3339
        timestamps.

        If the start date is omitted (`,2014-05-17T13:35:01-07:00`)
        anything updated before the end date will be returned.

        If the end date is omitted (`2014-05-15T13:35:01-07:00,`) the
        current date will be used as the end date instead., defaults to None
                :type updated_at_range: Optional[List[str]], optional
                :param size_range: Limits the search results to any items with a size within
        a given file size range. This applied to files and folders.

        Size ranges are defined as comma separated list of a lower
        and upper byte size limit (inclusive).

        The upper and lower bound can be omitted to create open ranges., defaults to None
                :type size_range: Optional[List[int]], optional
                :param owner_user_ids: Limits the search results to any items that are owned
        by the given list of owners, defined as a list of comma separated
        user IDs.

        The items still need to be owned or shared with
        the currently authenticated user for them to show up in the search
        results. If the user does not have access to any files owned by any of
        the users an empty result set will be returned.

        To search across an entire enterprise, we recommend using the
        `enterprise_content` scope parameter which can be requested with our
        support team., defaults to None
                :type owner_user_ids: Optional[List[str]], optional
                :param recent_updater_user_ids: Limits the search results to any items that have been updated
        by the given list of users, defined as a list of comma separated
        user IDs.

        The items still need to be owned or shared with
        the currently authenticated user for them to show up in the search
        results. If the user does not have access to any files owned by any of
        the users an empty result set will be returned.

        This feature only searches back to the last 10 versions of an item., defaults to None
                :type recent_updater_user_ids: Optional[List[str]], optional
                :param ancestor_folder_ids: Limits the search results to items within the given
        list of folders, defined as a comma separated lists
        of folder IDs.

        Search results will also include items within any subfolders
        of those ancestor folders.

        The folders still need to be owned or shared with
        the currently authenticated user. If the folder is not accessible by this
        user, or it does not exist, a `HTTP 404` error code will be returned
        instead.

        To search across an entire enterprise, we recommend using the
        `enterprise_content` scope parameter which can be requested with our
        support team., defaults to None
                :type ancestor_folder_ids: Optional[List[str]], optional
                :param content_types: Limits the search results to any items that match the search query
        for a specific part of the file, for example the file description.

        Content types are defined as a comma separated lists
        of Box recognized content types. The allowed content types are as follows.

        * `name` - The name of the item, as defined by its `name` field.
        * `description` - The description of the item, as defined by its
          `description` field.
        * `file_content` - The actual content of the file.
        * `comments` - The content of any of the comments on a file or
           folder.
        * `tags` - Any tags that are applied to an item, as defined by its
           `tags` field., defaults to None
                :type content_types: Optional[List[SearchForContentContentTypes]], optional
                :param type: Limits the search results to any items of this type. This
        parameter only takes one value. By default the API returns
        items that match any of these types.

        * `file` - Limits the search results to files,
        * `folder` - Limits the search results to folders,
        * `web_link` - Limits the search results to web links, also known
           as bookmarks., defaults to None
                :type type: Optional[SearchForContentType], optional
                :param trash_content: Determines if the search should look in the trash for items.

        By default, this API only returns search results for items
        not currently in the trash (`non_trashed_only`).

        * `trashed_only` - Only searches for items currently in the trash
        * `non_trashed_only` - Only searches for items currently not in
          the trash
        * `all_items` - Searches for both trashed and non-trashed items., defaults to None
                :type trash_content: Optional[SearchForContentTrashContent], optional
                :param mdfilters: Limits the search results to any items for which the metadata matches the provided filter.
        This parameter is a list that specifies exactly **one** metadata template used to filter the search results.
        The parameter is required unless the `query` parameter is provided., defaults to None
                :type mdfilters: Optional[List[MetadataFilter]], optional
                :param sort: Defines the order in which search results are returned. This API
        defaults to returning items by relevance unless this parameter is
        explicitly specified.

        * `relevance` (default) returns the results sorted by relevance to the
        query search term. The relevance is based on the occurrence of the search
        term in the items name, description, content, and additional properties.
        * `modified_at` returns the results ordered in descending order by date
        at which the item was last modified., defaults to None
                :type sort: Optional[SearchForContentSort], optional
                :param direction: Defines the direction in which search results are ordered. This API
        defaults to returning items in descending (`DESC`) order unless this
        parameter is explicitly specified.

        When results are sorted by `relevance` the ordering is locked to returning
        items in descending order of relevance, and this parameter is ignored., defaults to None
                :type direction: Optional[SearchForContentDirection], optional
                :param limit: Defines the maximum number of items to return as part of a page of
        results., defaults to None
                :type limit: Optional[int], optional
                :param include_recent_shared_links: Defines whether the search results should include any items
        that the user recently accessed through a shared link.

        When this parameter has been set to true,
        the format of the response of this API changes to return
        a list of [Search Results with
        Shared Links](https://developer.box.com/reference/resources/search-results-with-shared-links)., defaults to None
                :type include_recent_shared_links: Optional[bool], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param offset: The offset of the item at which to begin the response.

        Queries with offset parameter value
        exceeding 10000 will be rejected
        with a 400 response., defaults to None
                :type offset: Optional[int], optional
                :param deleted_user_ids: Limits the search results to items that were deleted by the given
        list of users, defined as a list of comma separated user IDs.

        The `trash_content` parameter needs to be set to `trashed_only`.

        If searching in trash is not performed, an empty result set
        is returned. The items need to be owned or shared with
        the currently authenticated user for them to show up in the search
        results.

        If the user does not have access to any files owned by
        any of the users, an empty result set is returned.

        Data available from 2023-02-01 onwards., defaults to None
                :type deleted_user_ids: Optional[List[str]], optional
                :param deleted_at_range: Limits the search results to any items deleted within a given
        date range.

        Date ranges are defined as comma separated RFC3339 timestamps.

        If the start date is omitted (`2014-05-17T13:35:01-07:00`),
        anything deleted before the end date will be returned.

        If the end date is omitted (`2014-05-15T13:35:01-07:00`),
        the current date will be used as the end date instead.

        The `trash_content` parameter needs to be set to `trashed_only`.

        If searching in trash is not performed, then an empty result
        is returned.

        Data available from 2023-02-01 onwards., defaults to None
                :type deleted_at_range: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'query': to_string(query),
                'scope': to_string(scope),
                'file_extensions': to_string(file_extensions),
                'created_at_range': to_string(created_at_range),
                'updated_at_range': to_string(updated_at_range),
                'size_range': to_string(size_range),
                'owner_user_ids': to_string(owner_user_ids),
                'recent_updater_user_ids': to_string(recent_updater_user_ids),
                'ancestor_folder_ids': to_string(ancestor_folder_ids),
                'content_types': to_string(content_types),
                'type': to_string(type),
                'trash_content': to_string(trash_content),
                'mdfilters': to_string(mdfilters),
                'sort': to_string(sort),
                'direction': to_string(direction),
                'limit': to_string(limit),
                'include_recent_shared_links': to_string(include_recent_shared_links),
                'fields': to_string(fields),
                'offset': to_string(offset),
                'deleted_user_ids': to_string(deleted_user_ids),
                'deleted_at_range': to_string(deleted_at_range),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join([self.network_session.base_urls.base_url, '/2.0/search']),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, SearchResultsResponse)



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class CollectionTypeField(str, Enum):
    COLLECTION = 'collection'


class CollectionNameField(str, Enum):
    FAVORITES = 'Favorites'


class CollectionCollectionTypeField(str, Enum):
    FAVORITES = 'favorites'


class Collection(BaseObject):
    _discriminator = 'type', {'collection'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[CollectionTypeField] = None,
        name: Optional[CollectionNameField] = None,
        collection_type: Optional[CollectionCollectionTypeField] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for this collection., defaults to None
                :type id: Optional[str], optional
                :param type: The value will always be `collection`., defaults to None
                :type type: Optional[CollectionTypeField], optional
                :param name: The name of the collection., defaults to None
                :type name: Optional[CollectionNameField], optional
                :param collection_type: The type of the collection. This is used to
        determine the proper visual treatment for
        collections., defaults to None
                :type collection_type: Optional[CollectionCollectionTypeField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.name = name
        self.collection_type = collection_type



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.trash_web_link_restored import TrashWebLinkRestored

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.trash_web_link import TrashWebLink

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class RestoreWeblinkFromTrashParent(BaseObject):
    def __init__(self, *, id: Optional[str] = None, **kwargs):
        """
        :param id: The ID of parent item., defaults to None
        :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id


class TrashedWebLinksManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def restore_weblink_from_trash(
        self,
        web_link_id: str,
        *,
        name: Optional[str] = None,
        parent: Optional[RestoreWeblinkFromTrashParent] = None,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> TrashWebLinkRestored:
        """
                Restores a web link that has been moved to the trash.

                An optional new parent ID can be provided to restore the  web link to in case


                the original folder has been deleted.

                :param web_link_id: The ID of the web link.
        Example: "12345"
                :type web_link_id: str
                :param name: An optional new name for the web link., defaults to None
                :type name: Optional[str], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'name': name, 'parent': parent}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/web_links/',
                        to_string(web_link_id),
                    ]
                ),
                method='POST',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, TrashWebLinkRestored)

    def get_trashed_web_link_by_id(
        self,
        web_link_id: str,
        *,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> TrashWebLink:
        """
                Retrieves a web link that has been moved to the trash.
                :param web_link_id: The ID of the web link.
        Example: "12345"
                :type web_link_id: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/web_links/',
                        to_string(web_link_id),
                        '/trash',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, TrashWebLink)

    def delete_trashed_web_link_by_id(
        self,
        web_link_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Permanently deletes a web link that is in the trash.

                This action cannot be undone.

                :param web_link_id: The ID of the web link.
        Example: "12345"
                :type web_link_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/web_links/',
                        to_string(web_link_id),
                        '/trash',
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.metadata_taxonomy_level import MetadataTaxonomyLevel

from box_sdk_gen.box.errors import BoxSDKError


class MetadataTaxonomyLevels(BaseObject):
    def __init__(
        self, *, entries: Optional[List[MetadataTaxonomyLevel]] = None, **kwargs
    ):
        """
        :param entries: An array of all taxonomy levels., defaults to None
        :type entries: Optional[List[MetadataTaxonomyLevel]], optional
        """
        super().__init__(**kwargs)
        self.entries = entries



from typing import Optional

from box_sdk_gen.schemas.web_link_base import WebLinkBaseTypeField

from box_sdk_gen.schemas.web_link_base import WebLinkBase

from box_sdk_gen.box.errors import BoxSDKError


class WebLinkMini(WebLinkBase):
    def __init__(
        self,
        id: str,
        *,
        url: Optional[str] = None,
        sequence_id: Optional[str] = None,
        name: Optional[str] = None,
        type: WebLinkBaseTypeField = WebLinkBaseTypeField.WEB_LINK,
        etag: Optional[str] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for this web link.
                :type id: str
                :param url: The URL this web link points to., defaults to None
                :type url: Optional[str], optional
                :param name: The name of the web link., defaults to None
                :type name: Optional[str], optional
                :param type: The value will always be `web_link`., defaults to WebLinkBaseTypeField.WEB_LINK
                :type type: WebLinkBaseTypeField, optional
                :param etag: The entity tag of this web link. Used with `If-Match`
        headers., defaults to None
                :type etag: Optional[str], optional
        """
        super().__init__(id=id, type=type, etag=etag, **kwargs)
        self.url = url
        self.sequence_id = sequence_id
        self.name = name



from typing import Optional

from typing import Dict

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.internal.utils import to_string

from typing import List

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.metadata_taxonomy import MetadataTaxonomy

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.metadata_taxonomies import MetadataTaxonomies

from box_sdk_gen.schemas.metadata_taxonomy_levels import MetadataTaxonomyLevels

from box_sdk_gen.schemas.metadata_taxonomy_level import MetadataTaxonomyLevel

from box_sdk_gen.schemas.metadata_taxonomy_nodes import MetadataTaxonomyNodes

from box_sdk_gen.schemas.metadata_taxonomy_node import MetadataTaxonomyNode

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import SerializedData

from box_sdk_gen.serialization.json import sd_to_json


class MetadataTaxonomiesManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def create_metadata_taxonomy(
        self,
        display_name: str,
        namespace: str,
        *,
        key: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataTaxonomy:
        """
                Creates a new metadata taxonomy that can be used in

                metadata templates.

                :param display_name: The display name of the taxonomy.
                :type display_name: str
                :param namespace: The namespace of the metadata taxonomy to create.
                :type namespace: str
                :param key: The taxonomy key. If it is not provided in the request body, it will be
        generated from the `displayName`. The `displayName` would be converted
        to lower case, and all spaces and non-alphanumeric characters replaced
        with underscores., defaults to None
                :type key: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'key': key,
            'displayName': display_name,
            'namespace': namespace,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_taxonomies',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataTaxonomy)

    def get_metadata_taxonomies(
        self,
        namespace: str,
        *,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataTaxonomies:
        """
                Used to retrieve all metadata taxonomies in a namespace.
                :param namespace: The namespace of the metadata taxonomy.
        Example: "enterprise_123456"
                :type namespace: str
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'marker': to_string(marker), 'limit': to_string(limit)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_taxonomies/',
                        to_string(namespace),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataTaxonomies)

    def get_metadata_taxonomy_by_key(
        self,
        namespace: str,
        taxonomy_key: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataTaxonomy:
        """
                Used to retrieve a metadata taxonomy by taxonomy key.
                :param namespace: The namespace of the metadata taxonomy.
        Example: "enterprise_123456"
                :type namespace: str
                :param taxonomy_key: The key of the metadata taxonomy.
        Example: "geography"
                :type taxonomy_key: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_taxonomies/',
                        to_string(namespace),
                        '/',
                        to_string(taxonomy_key),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataTaxonomy)

    def update_metadata_taxonomy(
        self,
        namespace: str,
        taxonomy_key: str,
        display_name: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataTaxonomy:
        """
                Updates an existing metadata taxonomy.
                :param namespace: The namespace of the metadata taxonomy.
        Example: "enterprise_123456"
                :type namespace: str
                :param taxonomy_key: The key of the metadata taxonomy.
        Example: "geography"
                :type taxonomy_key: str
                :param display_name: The display name of the taxonomy.
                :type display_name: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'displayName': display_name}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_taxonomies/',
                        to_string(namespace),
                        '/',
                        to_string(taxonomy_key),
                    ]
                ),
                method='PATCH',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataTaxonomy)

    def delete_metadata_taxonomy(
        self,
        namespace: str,
        taxonomy_key: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Delete a metadata taxonomy.

                This deletion is permanent and cannot be reverted.

                :param namespace: The namespace of the metadata taxonomy.
        Example: "enterprise_123456"
                :type namespace: str
                :param taxonomy_key: The key of the metadata taxonomy.
        Example: "geography"
                :type taxonomy_key: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_taxonomies/',
                        to_string(namespace),
                        '/',
                        to_string(taxonomy_key),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def create_metadata_taxonomy_level(
        self,
        namespace: str,
        taxonomy_key: str,
        request_body: List[MetadataTaxonomyLevel],
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataTaxonomyLevels:
        """
                Creates new metadata taxonomy levels.
                :param namespace: The namespace of the metadata taxonomy.
        Example: "enterprise_123456"
                :type namespace: str
                :param taxonomy_key: The key of the metadata taxonomy.
        Example: "geography"
                :type taxonomy_key: str
                :param request_body: Request body of createMetadataTaxonomyLevel method
                :type request_body: List[MetadataTaxonomyLevel]
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_taxonomies/',
                        to_string(namespace),
                        '/',
                        to_string(taxonomy_key),
                        '/levels',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataTaxonomyLevels)

    def update_metadata_taxonomy_level_by_id(
        self,
        namespace: str,
        taxonomy_key: str,
        level_index: int,
        display_name: str,
        *,
        description: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataTaxonomyLevel:
        """
                Updates an existing metadata taxonomy level.
                :param namespace: The namespace of the metadata taxonomy.
        Example: "enterprise_123456"
                :type namespace: str
                :param taxonomy_key: The key of the metadata taxonomy.
        Example: "geography"
                :type taxonomy_key: str
                :param level_index: The index of the metadata taxonomy level.
        Example: 1
                :type level_index: int
                :param display_name: The display name of the taxonomy level.
                :type display_name: str
                :param description: The description of the taxonomy level., defaults to None
                :type description: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'displayName': display_name, 'description': description}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_taxonomies/',
                        to_string(namespace),
                        '/',
                        to_string(taxonomy_key),
                        '/levels/',
                        to_string(level_index),
                    ]
                ),
                method='PATCH',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataTaxonomyLevel)

    def add_metadata_taxonomy_level(
        self,
        namespace: str,
        taxonomy_key: str,
        display_name: str,
        *,
        description: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataTaxonomyLevels:
        """
                Creates a new metadata taxonomy level and appends it to the existing levels.

                If there are no levels defined yet, this will create the first level.

                :param namespace: The namespace of the metadata taxonomy.
        Example: "enterprise_123456"
                :type namespace: str
                :param taxonomy_key: The key of the metadata taxonomy.
        Example: "geography"
                :type taxonomy_key: str
                :param display_name: The display name of the taxonomy level.
                :type display_name: str
                :param description: The description of the taxonomy level., defaults to None
                :type description: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'displayName': display_name, 'description': description}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_taxonomies/',
                        to_string(namespace),
                        '/',
                        to_string(taxonomy_key),
                        '/levels:append',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataTaxonomyLevels)

    def delete_metadata_taxonomy_level(
        self,
        namespace: str,
        taxonomy_key: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataTaxonomyLevels:
        """
                Deletes the last level of the metadata taxonomy.
                :param namespace: The namespace of the metadata taxonomy.
        Example: "enterprise_123456"
                :type namespace: str
                :param taxonomy_key: The key of the metadata taxonomy.
        Example: "geography"
                :type taxonomy_key: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_taxonomies/',
                        to_string(namespace),
                        '/',
                        to_string(taxonomy_key),
                        '/levels:trim',
                    ]
                ),
                method='POST',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataTaxonomyLevels)

    def get_metadata_taxonomy_nodes(
        self,
        namespace: str,
        taxonomy_key: str,
        *,
        level: Optional[List[int]] = None,
        parent: Optional[List[str]] = None,
        ancestor: Optional[List[str]] = None,
        query: Optional[str] = None,
        include_total_result_count: Optional[bool] = None,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataTaxonomyNodes:
        """
                Used to retrieve metadata taxonomy nodes based on the parameters specified.

                Results are sorted in lexicographic order unless a `query` parameter is passed.


                With a `query` parameter specified, results are sorted in order of relevance.

                :param namespace: The namespace of the metadata taxonomy.
        Example: "enterprise_123456"
                :type namespace: str
                :param taxonomy_key: The key of the metadata taxonomy.
        Example: "geography"
                :type taxonomy_key: str
                :param level: Filters results by taxonomy level. Multiple values can be provided.
        Results include nodes that match any of the specified values., defaults to None
                :type level: Optional[List[int]], optional
                :param parent: Node identifier of a direct parent node. Multiple values can be provided.
        Results include nodes that match any of the specified values., defaults to None
                :type parent: Optional[List[str]], optional
                :param ancestor: Node identifier of any ancestor node. Multiple values can be provided.
        Results include nodes that match any of the specified values., defaults to None
                :type ancestor: Optional[List[str]], optional
                :param query: Query text to search for the taxonomy nodes., defaults to None
                :type query: Optional[str], optional
                :param include_total_result_count: When set to `true` this provides the total number of nodes that matched the query.
        The response will compute counts of up to 10,000 elements. Defaults to `false`., defaults to None
                :type include_total_result_count: Optional[bool], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'level': to_string(level),
                'parent': to_string(parent),
                'ancestor': to_string(ancestor),
                'query': to_string(query),
                'include-total-result-count': to_string(include_total_result_count),
                'marker': to_string(marker),
                'limit': to_string(limit),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_taxonomies/',
                        to_string(namespace),
                        '/',
                        to_string(taxonomy_key),
                        '/nodes',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataTaxonomyNodes)

    def create_metadata_taxonomy_node(
        self,
        namespace: str,
        taxonomy_key: str,
        display_name: str,
        level: int,
        *,
        parent_id: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataTaxonomyNode:
        """
                Creates a new metadata taxonomy node.
                :param namespace: The namespace of the metadata taxonomy.
        Example: "enterprise_123456"
                :type namespace: str
                :param taxonomy_key: The key of the metadata taxonomy.
        Example: "geography"
                :type taxonomy_key: str
                :param display_name: The display name of the taxonomy node.
                :type display_name: str
                :param level: The level of the taxonomy node.
                :type level: int
                :param parent_id: The identifier of the parent taxonomy node.
        Omit this field for root-level nodes., defaults to None
                :type parent_id: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'displayName': display_name,
            'level': level,
            'parentId': parent_id,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_taxonomies/',
                        to_string(namespace),
                        '/',
                        to_string(taxonomy_key),
                        '/nodes',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataTaxonomyNode)

    def get_metadata_taxonomy_node_by_id(
        self,
        namespace: str,
        taxonomy_key: str,
        node_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataTaxonomyNode:
        """
                Retrieves a metadata taxonomy node by its identifier.
                :param namespace: The namespace of the metadata taxonomy.
        Example: "enterprise_123456"
                :type namespace: str
                :param taxonomy_key: The key of the metadata taxonomy.
        Example: "geography"
                :type taxonomy_key: str
                :param node_id: The identifier of the metadata taxonomy node.
        Example: "14d3d433-c77f-49c5-b146-9dea370f6e32"
                :type node_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_taxonomies/',
                        to_string(namespace),
                        '/',
                        to_string(taxonomy_key),
                        '/nodes/',
                        to_string(node_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataTaxonomyNode)

    def update_metadata_taxonomy_node(
        self,
        namespace: str,
        taxonomy_key: str,
        node_id: str,
        *,
        display_name: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataTaxonomyNode:
        """
                Updates an existing metadata taxonomy node.
                :param namespace: The namespace of the metadata taxonomy.
        Example: "enterprise_123456"
                :type namespace: str
                :param taxonomy_key: The key of the metadata taxonomy.
        Example: "geography"
                :type taxonomy_key: str
                :param node_id: The identifier of the metadata taxonomy node.
        Example: "14d3d433-c77f-49c5-b146-9dea370f6e32"
                :type node_id: str
                :param display_name: The display name of the taxonomy node., defaults to None
                :type display_name: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'displayName': display_name}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_taxonomies/',
                        to_string(namespace),
                        '/',
                        to_string(taxonomy_key),
                        '/nodes/',
                        to_string(node_id),
                    ]
                ),
                method='PATCH',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataTaxonomyNode)

    def delete_metadata_taxonomy_node(
        self,
        namespace: str,
        taxonomy_key: str,
        node_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Delete a metadata taxonomy node.

                This deletion is permanent and cannot be reverted.


                Only metadata taxonomy nodes without any children can be deleted.

                :param namespace: The namespace of the metadata taxonomy.
        Example: "enterprise_123456"
                :type namespace: str
                :param taxonomy_key: The key of the metadata taxonomy.
        Example: "geography"
                :type taxonomy_key: str
                :param node_id: The identifier of the metadata taxonomy node.
        Example: "14d3d433-c77f-49c5-b146-9dea370f6e32"
                :type node_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_taxonomies/',
                        to_string(namespace),
                        '/',
                        to_string(taxonomy_key),
                        '/nodes/',
                        to_string(node_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def get_metadata_template_field_options(
        self,
        namespace: str,
        template_key: str,
        field_key: str,
        *,
        level: Optional[List[int]] = None,
        parent: Optional[List[str]] = None,
        ancestor: Optional[List[str]] = None,
        query: Optional[str] = None,
        include_total_result_count: Optional[bool] = None,
        only_selectable_options: Optional[bool] = None,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataTaxonomyNodes:
        """
                Used to retrieve metadata taxonomy nodes which are available for the taxonomy field based

                on its configuration and the parameters specified.


                Results are sorted in lexicographic order unless a `query` parameter is passed.


                With a `query` parameter specified, results are sorted in order of relevance.

                :param namespace: The namespace of the metadata taxonomy.
        Example: "enterprise_123456"
                :type namespace: str
                :param template_key: The name of the metadata template.
        Example: "properties"
                :type template_key: str
                :param field_key: The key of the metadata taxonomy field in the template.
        Example: "geography"
                :type field_key: str
                :param level: Filters results by taxonomy level. Multiple values can be provided.
        Results include nodes that match any of the specified values., defaults to None
                :type level: Optional[List[int]], optional
                :param parent: Node identifier of a direct parent node. Multiple values can be provided.
        Results include nodes that match any of the specified values., defaults to None
                :type parent: Optional[List[str]], optional
                :param ancestor: Node identifier of any ancestor node. Multiple values can be provided.
        Results include nodes that match any of the specified values., defaults to None
                :type ancestor: Optional[List[str]], optional
                :param query: Query text to search for the taxonomy nodes., defaults to None
                :type query: Optional[str], optional
                :param include_total_result_count: When set to `true` this provides the total number of nodes that matched the query.
        The response will compute counts of up to 10,000 elements. Defaults to `false`., defaults to None
                :type include_total_result_count: Optional[bool], optional
                :param only_selectable_options: When set to `true`, this only returns valid selectable options for this template
        taxonomy field. Otherwise, it returns all taxonomy nodes, whether or not they are selectable.
        Defaults to `true`., defaults to None
                :type only_selectable_options: Optional[bool], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'level': to_string(level),
                'parent': to_string(parent),
                'ancestor': to_string(ancestor),
                'query': to_string(query),
                'include-total-result-count': to_string(include_total_result_count),
                'only-selectable-options': to_string(only_selectable_options),
                'marker': to_string(marker),
                'limit': to_string(limit),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_templates/',
                        to_string(namespace),
                        '/',
                        to_string(template_key),
                        '/fields/',
                        to_string(field_key),
                        '/options',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataTaxonomyNodes)



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class HubUpdateRequestV2025R0(BaseObject):
    def __init__(
        self,
        *,
        title: Optional[str] = None,
        description: Optional[str] = None,
        is_ai_enabled: Optional[bool] = None,
        is_collaboration_restricted_to_enterprise: Optional[bool] = None,
        can_non_owners_invite: Optional[bool] = None,
        can_shared_link_be_created: Optional[bool] = None,
        can_public_shared_link_be_created: Optional[bool] = None,
        **kwargs
    ):
        """
        :param title: Title of the Box Hub. It cannot be empty and should be less than 50 characters., defaults to None
        :type title: Optional[str], optional
        :param description: Description of the Box Hub., defaults to None
        :type description: Optional[str], optional
        :param is_ai_enabled: Indicates if AI features are enabled for the Box Hub., defaults to None
        :type is_ai_enabled: Optional[bool], optional
        :param is_collaboration_restricted_to_enterprise: Indicates if collaboration is restricted to the enterprise., defaults to None
        :type is_collaboration_restricted_to_enterprise: Optional[bool], optional
        :param can_non_owners_invite: Indicates if non-owners can invite others to the Box Hub., defaults to None
        :type can_non_owners_invite: Optional[bool], optional
        :param can_shared_link_be_created: Indicates if a shared link can be created for the Box Hub., defaults to None
        :type can_shared_link_be_created: Optional[bool], optional
        :param can_public_shared_link_be_created: Indicates if a public shared link can be created for the Box Hub., defaults to None
        :type can_public_shared_link_be_created: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.title = title
        self.description = description
        self.is_ai_enabled = is_ai_enabled
        self.is_collaboration_restricted_to_enterprise = (
            is_collaboration_restricted_to_enterprise
        )
        self.can_non_owners_invite = can_non_owners_invite
        self.can_shared_link_be_created = can_shared_link_be_created
        self.can_public_shared_link_be_created = can_public_shared_link_be_created



from enum import Enum

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.classification_template import ClassificationTemplate

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import SerializedData


class AddClassificationRequestBodyOpField(str, Enum):
    ADDENUMOPTION = 'addEnumOption'


class AddClassificationRequestBodyFieldKeyField(str, Enum):
    BOX__SECURITY__CLASSIFICATION__KEY = 'Box__Security__Classification__Key'


class AddClassificationRequestBodyDataStaticConfigClassificationField(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'classification_definition': 'classificationDefinition',
        'color_id': 'colorID',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'classificationDefinition': 'classification_definition',
        'colorID': 'color_id',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        *,
        classification_definition: Optional[str] = None,
        color_id: Optional[int] = None,
        **kwargs
    ):
        """
                :param classification_definition: A longer description of the classification., defaults to None
                :type classification_definition: Optional[str], optional
                :param color_id: An internal Box identifier used to assign a color to
        a classification label.

        Mapping between a `colorID` and a color may change
        without notice. Currently, the color mappings are as
        follows.

        * `0`: Yellow.
        * `1`: Orange.
        * `2`: Watermelon red.
        * `3`: Purple rain.
        * `4`: Light blue.
        * `5`: Dark blue.
        * `6`: Light green.
        * `7`: Gray., defaults to None
                :type color_id: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.classification_definition = classification_definition
        self.color_id = color_id


class AddClassificationRequestBodyDataStaticConfigField(BaseObject):
    def __init__(
        self,
        *,
        classification: Optional[
            AddClassificationRequestBodyDataStaticConfigClassificationField
        ] = None,
        **kwargs
    ):
        """
        :param classification: Additional details for the classification., defaults to None
        :type classification: Optional[AddClassificationRequestBodyDataStaticConfigClassificationField], optional
        """
        super().__init__(**kwargs)
        self.classification = classification


class AddClassificationRequestBodyDataField(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'static_config': 'staticConfig',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'staticConfig': 'static_config',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        key: str,
        *,
        static_config: Optional[
            AddClassificationRequestBodyDataStaticConfigField
        ] = None,
        **kwargs
    ):
        """
                :param key: The label of the classification as shown in the web and
        mobile interfaces. This is the only field required to
        add a classification.
                :type key: str
                :param static_config: A static configuration for the classification., defaults to None
                :type static_config: Optional[AddClassificationRequestBodyDataStaticConfigField], optional
        """
        super().__init__(**kwargs)
        self.key = key
        self.static_config = static_config


class AddClassificationRequestBody(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'field_key': 'fieldKey',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'fieldKey': 'field_key',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        data: AddClassificationRequestBodyDataField,
        *,
        op: AddClassificationRequestBodyOpField = AddClassificationRequestBodyOpField.ADDENUMOPTION,
        field_key: AddClassificationRequestBodyFieldKeyField = AddClassificationRequestBodyFieldKeyField.BOX__SECURITY__CLASSIFICATION__KEY,
        **kwargs
    ):
        """
                :param data: The details of the classification to add.
                :type data: AddClassificationRequestBodyDataField
                :param op: The type of change to perform on the classification
        object., defaults to AddClassificationRequestBodyOpField.ADDENUMOPTION
                :type op: AddClassificationRequestBodyOpField, optional
                :param field_key: Defines classifications
        available in the enterprise., defaults to AddClassificationRequestBodyFieldKeyField.BOX__SECURITY__CLASSIFICATION__KEY
                :type field_key: AddClassificationRequestBodyFieldKeyField, optional
        """
        super().__init__(**kwargs)
        self.data = data
        self.op = op
        self.field_key = field_key


class UpdateClassificationRequestBodyOpField(str, Enum):
    EDITENUMOPTION = 'editEnumOption'


class UpdateClassificationRequestBodyFieldKeyField(str, Enum):
    BOX__SECURITY__CLASSIFICATION__KEY = 'Box__Security__Classification__Key'


class UpdateClassificationRequestBodyDataStaticConfigClassificationField(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'classification_definition': 'classificationDefinition',
        'color_id': 'colorID',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'classificationDefinition': 'classification_definition',
        'colorID': 'color_id',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        *,
        classification_definition: Optional[str] = None,
        color_id: Optional[int] = None,
        **kwargs
    ):
        """
                :param classification_definition: A longer description of the classification., defaults to None
                :type classification_definition: Optional[str], optional
                :param color_id: An internal Box identifier used to assign a color to
        a classification label.

        Mapping between a `colorID` and a color may change
        without notice. Currently, the color mappings are as
        follows.

        * `0`: Yellow.
        * `1`: Orange.
        * `2`: Watermelon red.
        * `3`: Purple rain.
        * `4`: Light blue.
        * `5`: Dark blue.
        * `6`: Light green.
        * `7`: Gray., defaults to None
                :type color_id: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.classification_definition = classification_definition
        self.color_id = color_id


class UpdateClassificationRequestBodyDataStaticConfigField(BaseObject):
    def __init__(
        self,
        *,
        classification: Optional[
            UpdateClassificationRequestBodyDataStaticConfigClassificationField
        ] = None,
        **kwargs
    ):
        """
        :param classification: Additional details for the classification., defaults to None
        :type classification: Optional[UpdateClassificationRequestBodyDataStaticConfigClassificationField], optional
        """
        super().__init__(**kwargs)
        self.classification = classification


class UpdateClassificationRequestBodyDataField(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'static_config': 'staticConfig',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'staticConfig': 'static_config',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        key: str,
        *,
        static_config: Optional[
            UpdateClassificationRequestBodyDataStaticConfigField
        ] = None,
        **kwargs
    ):
        """
                :param key: A new label for the classification, as it will be
        shown in the web and mobile interfaces.
                :type key: str
                :param static_config: A static configuration for the classification., defaults to None
                :type static_config: Optional[UpdateClassificationRequestBodyDataStaticConfigField], optional
        """
        super().__init__(**kwargs)
        self.key = key
        self.static_config = static_config


class UpdateClassificationRequestBody(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'field_key': 'fieldKey',
        'enum_option_key': 'enumOptionKey',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'fieldKey': 'field_key',
        'enumOptionKey': 'enum_option_key',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        enum_option_key: str,
        data: UpdateClassificationRequestBodyDataField,
        *,
        op: UpdateClassificationRequestBodyOpField = UpdateClassificationRequestBodyOpField.EDITENUMOPTION,
        field_key: UpdateClassificationRequestBodyFieldKeyField = UpdateClassificationRequestBodyFieldKeyField.BOX__SECURITY__CLASSIFICATION__KEY,
        **kwargs
    ):
        """
                :param enum_option_key: The original label of the classification to change.
                :type enum_option_key: str
                :param data: The details of the updated classification.
                :type data: UpdateClassificationRequestBodyDataField
                :param op: The type of change to perform on the classification
        object., defaults to UpdateClassificationRequestBodyOpField.EDITENUMOPTION
                :type op: UpdateClassificationRequestBodyOpField, optional
                :param field_key: Defines classifications
        available in the enterprise., defaults to UpdateClassificationRequestBodyFieldKeyField.BOX__SECURITY__CLASSIFICATION__KEY
                :type field_key: UpdateClassificationRequestBodyFieldKeyField, optional
        """
        super().__init__(**kwargs)
        self.enum_option_key = enum_option_key
        self.data = data
        self.op = op
        self.field_key = field_key


class CreateClassificationTemplateScope(str, Enum):
    ENTERPRISE = 'enterprise'


class CreateClassificationTemplateTemplateKey(str, Enum):
    SECURITYCLASSIFICATION_6VMVOCHWUWO = 'securityClassification-6VMVochwUWo'


class CreateClassificationTemplateDisplayName(str, Enum):
    CLASSIFICATION = 'Classification'


class CreateClassificationTemplateFieldsTypeField(str, Enum):
    ENUM = 'enum'


class CreateClassificationTemplateFieldsKeyField(str, Enum):
    BOX__SECURITY__CLASSIFICATION__KEY = 'Box__Security__Classification__Key'


class CreateClassificationTemplateFieldsDisplayNameField(str, Enum):
    CLASSIFICATION = 'Classification'


class CreateClassificationTemplateFieldsOptionsStaticConfigClassificationField(
    BaseObject
):
    _fields_to_json_mapping: Dict[str, str] = {
        'classification_definition': 'classificationDefinition',
        'color_id': 'colorID',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'classificationDefinition': 'classification_definition',
        'colorID': 'color_id',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        *,
        classification_definition: Optional[str] = None,
        color_id: Optional[int] = None,
        **kwargs
    ):
        """
                :param classification_definition: A longer description of the classification., defaults to None
                :type classification_definition: Optional[str], optional
                :param color_id: An identifier used to assign a color to
        a classification label.

        Mapping between a `colorID` and a color may
        change without notice. Currently, the color
        mappings are as follows.

        * `0`: Yellow.
        * `1`: Orange.
        * `2`: Watermelon red.
        * `3`: Purple rain.
        * `4`: Light blue.
        * `5`: Dark blue.
        * `6`: Light green.
        * `7`: Gray., defaults to None
                :type color_id: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.classification_definition = classification_definition
        self.color_id = color_id


class CreateClassificationTemplateFieldsOptionsStaticConfigField(BaseObject):
    def __init__(
        self,
        *,
        classification: Optional[
            CreateClassificationTemplateFieldsOptionsStaticConfigClassificationField
        ] = None,
        **kwargs
    ):
        """
        :param classification: Additional information about the classification., defaults to None
        :type classification: Optional[CreateClassificationTemplateFieldsOptionsStaticConfigClassificationField], optional
        """
        super().__init__(**kwargs)
        self.classification = classification


class CreateClassificationTemplateFieldsOptionsField(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'static_config': 'staticConfig',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'staticConfig': 'static_config',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        key: str,
        *,
        static_config: Optional[
            CreateClassificationTemplateFieldsOptionsStaticConfigField
        ] = None,
        **kwargs
    ):
        """
                :param key: The display name and key this classification. This
        will be show in the Box UI.
                :type key: str
                :param static_config: Additional information about the classification., defaults to None
                :type static_config: Optional[CreateClassificationTemplateFieldsOptionsStaticConfigField], optional
        """
        super().__init__(**kwargs)
        self.key = key
        self.static_config = static_config


class CreateClassificationTemplateFields(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'display_name': 'displayName',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'displayName': 'display_name',
        **BaseObject._json_to_fields_mapping,
    }
    _discriminator = 'type', {'enum'}

    def __init__(
        self,
        options: List[CreateClassificationTemplateFieldsOptionsField],
        *,
        type: CreateClassificationTemplateFieldsTypeField = CreateClassificationTemplateFieldsTypeField.ENUM,
        key: CreateClassificationTemplateFieldsKeyField = CreateClassificationTemplateFieldsKeyField.BOX__SECURITY__CLASSIFICATION__KEY,
        display_name: CreateClassificationTemplateFieldsDisplayNameField = CreateClassificationTemplateFieldsDisplayNameField.CLASSIFICATION,
        hidden: Optional[bool] = None,
        **kwargs
    ):
        """
                :param options: The actual list of classifications that are present on
        this template.
                :type options: List[CreateClassificationTemplateFieldsOptionsField]
                :param type: The type of the field
        that is always enum., defaults to CreateClassificationTemplateFieldsTypeField.ENUM
                :type type: CreateClassificationTemplateFieldsTypeField, optional
                :param key: Defines classifications
        available in the enterprise., defaults to CreateClassificationTemplateFieldsKeyField.BOX__SECURITY__CLASSIFICATION__KEY
                :type key: CreateClassificationTemplateFieldsKeyField, optional
                :param display_name: A display name for the classification., defaults to CreateClassificationTemplateFieldsDisplayNameField.CLASSIFICATION
                :type display_name: CreateClassificationTemplateFieldsDisplayNameField, optional
                :param hidden: Determines if the classification
        template is
        hidden or available on
        web and mobile
        devices., defaults to None
                :type hidden: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.options = options
        self.type = type
        self.key = key
        self.display_name = display_name
        self.hidden = hidden


class ClassificationsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_classification_template(
        self, *, extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ClassificationTemplate:
        """
        Retrieves the classification metadata template and lists all the

        classifications available to this enterprise.


        This API can also be called by including the enterprise ID in the


        URL explicitly, for example


        `/metadata_templates/enterprise_12345/securityClassification-6VMVochwUWo/schema`.

        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_templates/enterprise/securityClassification-6VMVochwUWo/schema',
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, ClassificationTemplate)

    def add_classification(
        self,
        request_body: List[AddClassificationRequestBody],
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ClassificationTemplate:
        """
        Adds one or more new classifications to the list of classifications

        available to the enterprise.


        This API can also be called by including the enterprise ID in the


        URL explicitly, for example


        `/metadata_templates/enterprise_12345/securityClassification-6VMVochwUWo/schema`.

        :param request_body: Request body of addClassification method
        :type request_body: List[AddClassificationRequestBody]
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_templates/enterprise/securityClassification-6VMVochwUWo/schema#add',
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, ClassificationTemplate)

    def update_classification(
        self,
        request_body: List[UpdateClassificationRequestBody],
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ClassificationTemplate:
        """
        Updates the labels and descriptions of one or more classifications

        available to the enterprise.


        This API can also be called by including the enterprise ID in the


        URL explicitly, for example


        `/metadata_templates/enterprise_12345/securityClassification-6VMVochwUWo/schema`.

        :param request_body: Request body of updateClassification method
        :type request_body: List[UpdateClassificationRequestBody]
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_templates/enterprise/securityClassification-6VMVochwUWo/schema#update',
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json-patch+json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, ClassificationTemplate)

    def create_classification_template(
        self,
        fields: List[CreateClassificationTemplateFields],
        *,
        scope: CreateClassificationTemplateScope = CreateClassificationTemplateScope.ENTERPRISE,
        template_key: CreateClassificationTemplateTemplateKey = CreateClassificationTemplateTemplateKey.SECURITYCLASSIFICATION_6VMVOCHWUWO,
        display_name: CreateClassificationTemplateDisplayName = CreateClassificationTemplateDisplayName.CLASSIFICATION,
        hidden: Optional[bool] = None,
        copy_instance_on_item_copy: Optional[bool] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ClassificationTemplate:
        """
                When an enterprise does not yet have any classifications, this API call

                initializes the classification template with an initial set of


                classifications.


                If an enterprise already has a classification, the template will already


                exist and instead an API call should be made to add additional


                classifications.

                :param fields: The classification template requires exactly
        one field, which holds
        all the valid classification values.
                :type fields: List[CreateClassificationTemplateFields]
                :param scope: The scope in which to create the classifications. This should
        be `enterprise` or `enterprise_{id}` where `id` is the unique
        ID of the enterprise., defaults to CreateClassificationTemplateScope.ENTERPRISE
                :type scope: CreateClassificationTemplateScope, optional
                :param template_key: Defines the list of metadata templates., defaults to CreateClassificationTemplateTemplateKey.SECURITYCLASSIFICATION_6VMVOCHWUWO
                :type template_key: CreateClassificationTemplateTemplateKey, optional
                :param display_name: The name of the
        template as shown in web and mobile interfaces., defaults to CreateClassificationTemplateDisplayName.CLASSIFICATION
                :type display_name: CreateClassificationTemplateDisplayName, optional
                :param hidden: Determines if the classification template is
        hidden or available on web and mobile
        devices., defaults to None
                :type hidden: Optional[bool], optional
                :param copy_instance_on_item_copy: Determines if classifications are
        copied along when the file or folder is
        copied., defaults to None
                :type copy_instance_on_item_copy: Optional[bool], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'scope': scope,
            'templateKey': template_key,
            'displayName': display_name,
            'hidden': hidden,
            'copyInstanceOnItemCopy': copy_instance_on_item_copy,
            'fields': fields,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_templates/schema#classifications',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, ClassificationTemplate)



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class MetadataError(BaseObject):
    def __init__(
        self,
        *,
        code: Optional[str] = None,
        message: Optional[str] = None,
        request_id: Optional[str] = None,
        **kwargs
    ):
        """
                :param code: A Box-specific error code., defaults to None
                :type code: Optional[str], optional
                :param message: A short message describing the error., defaults to None
                :type message: Optional[str], optional
                :param request_id: A unique identifier for this response, which can be used
        when contacting Box support., defaults to None
                :type request_id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.code = code
        self.message = message
        self.request_id = request_id



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class SessionTerminationMessage(BaseObject):
    def __init__(self, *, message: Optional[str] = None, **kwargs):
        """
        :param message: The unique identifier for the termination job status., defaults to None
        :type message: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.message = message



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.terms_of_service_base import TermsOfServiceBase

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class TermsOfServiceUserStatusTypeField(str, Enum):
    TERMS_OF_SERVICE_USER_STATUS = 'terms_of_service_user_status'


class TermsOfServiceUserStatus(BaseObject):
    _discriminator = 'type', {'terms_of_service_user_status'}

    def __init__(
        self,
        id: str,
        *,
        type: TermsOfServiceUserStatusTypeField = TermsOfServiceUserStatusTypeField.TERMS_OF_SERVICE_USER_STATUS,
        tos: Optional[TermsOfServiceBase] = None,
        user: Optional[UserMini] = None,
        is_accepted: Optional[bool] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier for this terms of service user status.
        :type id: str
        :param type: The value will always be `terms_of_service_user_status`., defaults to TermsOfServiceUserStatusTypeField.TERMS_OF_SERVICE_USER_STATUS
        :type type: TermsOfServiceUserStatusTypeField, optional
        :param is_accepted: If the user has accepted the terms of services., defaults to None
        :type is_accepted: Optional[bool], optional
        :param created_at: When the legal item was created., defaults to None
        :type created_at: Optional[DateTime], optional
        :param modified_at: When the legal item was modified., defaults to None
        :type modified_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.tos = tos
        self.user = user
        self.is_accepted = is_accepted
        self.created_at = created_at
        self.modified_at = modified_at



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class CompletionRuleVariableTypeField(str, Enum):
    VARIABLE = 'variable'


class CompletionRuleVariableVariableTypeField(str, Enum):
    TASK_COMPLETION_RULE = 'task_completion_rule'


class CompletionRuleVariableVariableValueField(str, Enum):
    ALL_ASSIGNEES = 'all_assignees'
    ANY_ASSIGNEES = 'any_assignees'


class CompletionRuleVariable(BaseObject):
    _discriminator = 'type', {'variable'}

    def __init__(
        self,
        variable_value: CompletionRuleVariableVariableValueField,
        *,
        type: CompletionRuleVariableTypeField = CompletionRuleVariableTypeField.VARIABLE,
        variable_type: CompletionRuleVariableVariableTypeField = CompletionRuleVariableVariableTypeField.TASK_COMPLETION_RULE,
        **kwargs
    ):
        """
                :param variable_value: Variable
        values for a completion
        rule.
                :type variable_value: CompletionRuleVariableVariableValueField
                :param type: Completion
        Rule object type., defaults to CompletionRuleVariableTypeField.VARIABLE
                :type type: CompletionRuleVariableTypeField, optional
                :param variable_type: Variable type
        for the Completion
        Rule object., defaults to CompletionRuleVariableVariableTypeField.TASK_COMPLETION_RULE
                :type variable_type: CompletionRuleVariableVariableTypeField, optional
        """
        super().__init__(**kwargs)
        self.variable_value = variable_value
        self.type = type
        self.variable_type = variable_type



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class StoragePolicyMiniTypeField(str, Enum):
    STORAGE_POLICY = 'storage_policy'


class StoragePolicyMini(BaseObject):
    _discriminator = 'type', {'storage_policy'}

    def __init__(
        self,
        id: str,
        *,
        type: StoragePolicyMiniTypeField = StoragePolicyMiniTypeField.STORAGE_POLICY,
        **kwargs
    ):
        """
        :param id: The unique identifier for this storage policy.
        :type id: str
        :param type: The value will always be `storage_policy`., defaults to StoragePolicyMiniTypeField.STORAGE_POLICY
        :type type: StoragePolicyMiniTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type



from enum import Enum

from typing import Optional

from box_sdk_gen.schemas.v2025_r0.doc_gen_job_base_v2025_r0 import (
    DocGenJobBaseV2025R0TypeField,
)

from box_sdk_gen.schemas.v2025_r0.doc_gen_job_base_v2025_r0 import DocGenJobBaseV2025R0

from box_sdk_gen.schemas.v2025_r0.doc_gen_batch_base_v2025_r0 import (
    DocGenBatchBaseV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.file_reference_v2025_r0 import FileReferenceV2025R0

from box_sdk_gen.schemas.v2025_r0.file_version_base_v2025_r0 import (
    FileVersionBaseV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError


class DocGenJobV2025R0StatusField(str, Enum):
    SUBMITTED = 'submitted'
    COMPLETED = 'completed'
    FAILED = 'failed'
    COMPLETED_WITH_ERROR = 'completed_with_error'
    PENDING = 'pending'


class DocGenJobV2025R0(DocGenJobBaseV2025R0):
    def __init__(
        self,
        batch: DocGenBatchBaseV2025R0,
        template_file: FileReferenceV2025R0,
        template_file_version: FileVersionBaseV2025R0,
        status: DocGenJobV2025R0StatusField,
        output_type: str,
        id: str,
        *,
        output_file: Optional[FileReferenceV2025R0] = None,
        output_file_version: Optional[FileVersionBaseV2025R0] = None,
        type: DocGenJobBaseV2025R0TypeField = DocGenJobBaseV2025R0TypeField.DOCGEN_JOB,
        **kwargs
    ):
        """
        :param status: Status of the job.
        :type status: DocGenJobV2025R0StatusField
        :param output_type: Type of the generated file.
        :type output_type: str
        :param id: The unique identifier that represent a Box Doc Gen job.
        :type id: str
        :param type: The value will always be `docgen_job`., defaults to DocGenJobBaseV2025R0TypeField.DOCGEN_JOB
        :type type: DocGenJobBaseV2025R0TypeField, optional
        """
        super().__init__(id=id, type=type, **kwargs)
        self.batch = batch
        self.template_file = template_file
        self.template_file_version = template_file_version
        self.status = status
        self.output_type = output_type
        self.output_file = output_file
        self.output_file_version = output_file_version



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.v2025_r0.file_reference_v2025_r0 import FileReferenceV2025R0

from box_sdk_gen.schemas.v2025_r0.folder_reference_v2025_r0 import (
    FolderReferenceV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.weblink_reference_v2025_r0 import (
    WeblinkReferenceV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.hub_item_reference_v2025_r0 import (
    HubItemReferenceV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError


class HubItemOperationV2025R0ActionField(str, Enum):
    ADD = 'add'
    REMOVE = 'remove'


class HubItemOperationV2025R0(BaseObject):
    def __init__(
        self,
        action: HubItemOperationV2025R0ActionField,
        item: HubItemReferenceV2025R0,
        **kwargs
    ):
        """
        :param action: The action to perform on a Box Hub item.
        :type action: HubItemOperationV2025R0ActionField
        """
        super().__init__(**kwargs)
        self.action = action
        self.item = item



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class SignRequestSignerInputDateAsiaValidationValidationTypeField(str, Enum):
    DATE_ASIA = 'date_asia'


class SignRequestSignerInputDateAsiaValidation(BaseObject):
    def __init__(
        self,
        *,
        validation_type: Optional[
            SignRequestSignerInputDateAsiaValidationValidationTypeField
        ] = None,
        **kwargs
    ):
        """
        :param validation_type: Validates that the text input uses the Asian date format `YYYY/MM/DD`., defaults to None
        :type validation_type: Optional[SignRequestSignerInputDateAsiaValidationValidationTypeField], optional
        """
        super().__init__(**kwargs)
        self.validation_type = validation_type



import json
from typing import Dict, get_origin, Union, Type
from urllib.parse import urlencode

from ..internal.base_object import BaseObject

SerializedData = Dict


def json_to_serialized_data(data: str) -> SerializedData:
    return json.loads(data)


def sd_to_json(data: SerializedData) -> str:
    return json.dumps(data)


def sd_to_url_params(data: SerializedData) -> str:
    return urlencode(data)


def get_sd_value_by_key(data: SerializedData, key: str):
    return data.get(key)


def serialize(obj: Union[BaseObject, dict, list]) -> SerializedData:
    if isinstance(obj, dict):
        obj = BaseObject(**obj).to_dict()
    if isinstance(obj, BaseObject):
        obj = obj.to_dict()
    if isinstance(obj, list):
        obj = [
            element.to_dict() if isinstance(element, BaseObject) else element
            for element in obj
        ]
    return obj


def deserialize(value: SerializedData, type: Type[BaseObject]):
    if get_origin(type) == Union:
        type = BaseObject._deserialize_union('', value, type)
    obj = type.from_dict(value)
    obj._raw_data = value
    return obj


def sanitized_value() -> str:
    return '---[redacted]---'


def sanitize_serialized_data(
    sd: SerializedData, keys_to_sanitize: Dict[str, str]
) -> SerializedData:
    if not isinstance(sd, Dict):
        return sd
    sanitized_dictionary = {}
    for key, value in sd.items():
        if key.lower() in keys_to_sanitize and isinstance(value, str):
            sanitized_dictionary[key] = sanitized_value()
        elif isinstance(value, Dict):
            sanitized_dictionary[key] = sanitize_serialized_data(
                value, keys_to_sanitize
            )
        else:
            sanitized_dictionary[key] = value
    return sanitized_dictionary



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class PostOAuth2TokenRefreshAccessTokenGrantTypeField(str, Enum):
    REFRESH_TOKEN = 'refresh_token'


class PostOAuth2TokenRefreshAccessToken(BaseObject):
    def __init__(
        self,
        client_id: str,
        client_secret: str,
        refresh_token: str,
        *,
        grant_type: PostOAuth2TokenRefreshAccessTokenGrantTypeField = PostOAuth2TokenRefreshAccessTokenGrantTypeField.REFRESH_TOKEN,
        **kwargs
    ):
        """
        :param client_id: The client ID of the application requesting to refresh the token.
        :type client_id: str
        :param client_secret: The client secret of the application requesting to refresh the token.
        :type client_secret: str
        :param refresh_token: The refresh token to refresh.
        :type refresh_token: str
        :param grant_type: The type of request being made, in this case a refresh request., defaults to PostOAuth2TokenRefreshAccessTokenGrantTypeField.REFRESH_TOKEN
        :type grant_type: PostOAuth2TokenRefreshAccessTokenGrantTypeField, optional
        """
        super().__init__(**kwargs)
        self.client_id = client_id
        self.client_secret = client_secret
        self.refresh_token = refresh_token
        self.grant_type = grant_type



from typing import Optional

from box_sdk_gen.schemas.user_base import UserBaseTypeField

from box_sdk_gen.schemas.user_base import UserBase

from box_sdk_gen.box.errors import BoxSDKError


class UserIntegrationMappings(UserBase):
    def __init__(
        self,
        id: str,
        *,
        name: Optional[str] = None,
        login: Optional[str] = None,
        type: UserBaseTypeField = UserBaseTypeField.USER,
        **kwargs
    ):
        """
        :param id: The unique identifier for this user.
        :type id: str
        :param name: The display name of this user., defaults to None
        :type name: Optional[str], optional
        :param login: The primary email address of this user., defaults to None
        :type login: Optional[str], optional
        :param type: The value will always be `user`., defaults to UserBaseTypeField.USER
        :type type: UserBaseTypeField, optional
        """
        super().__init__(id=id, type=type, **kwargs)
        self.name = name
        self.login = login



from typing import Optional

from typing import List

from box_sdk_gen.internal.utils import DateTime

from box_sdk_gen.schemas.ai_agent_info import AiAgentInfo

from box_sdk_gen.schemas.ai_response import AiResponse

from box_sdk_gen.schemas.ai_citation import AiCitation

from box_sdk_gen.box.errors import BoxSDKError


class AiResponseFull(AiResponse):
    def __init__(
        self,
        answer: str,
        created_at: DateTime,
        *,
        citations: Optional[List[AiCitation]] = None,
        completion_reason: Optional[str] = None,
        ai_agent_info: Optional[AiAgentInfo] = None,
        **kwargs
    ):
        """
        :param answer: The answer provided by the LLM.
        :type answer: str
        :param created_at: The ISO date formatted timestamp of when the answer to the prompt was created.
        :type created_at: DateTime
        :param citations: The citations of the LLM's answer reference., defaults to None
        :type citations: Optional[List[AiCitation]], optional
        :param completion_reason: The reason the response finishes., defaults to None
        :type completion_reason: Optional[str], optional
        """
        super().__init__(
            answer=answer,
            created_at=created_at,
            completion_reason=completion_reason,
            ai_agent_info=ai_agent_info,
            **kwargs
        )
        self.citations = citations



from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class DocGenDocumentGenerationDataV2025R0(BaseObject):
    def __init__(self, generated_file_name: str, user_input: Dict, **kwargs):
        """
        :param generated_file_name: File name of the output file.
        :type generated_file_name: str
        """
        super().__init__(**kwargs)
        self.generated_file_name = generated_file_name
        self.user_input = user_input



from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.metadata_taxonomy_level import MetadataTaxonomyLevel

from box_sdk_gen.box.errors import BoxSDKError


class MetadataTaxonomy(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'display_name': 'displayName',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'displayName': 'display_name',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        id: str,
        display_name: str,
        namespace: str,
        *,
        key: Optional[str] = None,
        levels: Optional[List[MetadataTaxonomyLevel]] = None,
        **kwargs
    ):
        """
                :param id: A unique identifier of the metadata taxonomy.
                :type id: str
                :param display_name: The display name of the metadata taxonomy. This can be seen in the Box web app.
                :type display_name: str
                :param namespace: A namespace that the metadata taxonomy is associated with.
                :type namespace: str
                :param key: A unique identifier of the metadata taxonomy. The identifier must be unique within
        the namespace to which it belongs., defaults to None
                :type key: Optional[str], optional
                :param levels: Levels of the metadata taxonomy., defaults to None
                :type levels: Optional[List[MetadataTaxonomyLevel]], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.display_name = display_name
        self.namespace = namespace
        self.key = key
        self.levels = levels
